==> 2.7.13.tar.gz: lib/src/model/labels.dart <==
class UsercentricsLabels {
  const UsercentricsLabels({
    required this.btnAcceptAll,
    required this.btnDeny,
    required this.btnSave,
    required this.firstLayerTitle,
    required this.accepted,
    required this.denied,
    required this.date,
    required this.decision,
    required this.dataCollectedList,
    required this.dataCollectedInfo,
    required this.locationOfProcessing,
    required this.transferToThirdCountries,
    required this.dataPurposes,
    required this.dataPurposesInfo,
    required this.dataRecipientsList,
    required this.descriptionOfService,
    required this.history,
    required this.historyDescription,
    required this.legalBasisList,
    required this.legalBasisInfo,
    required this.processingCompanyTitle,
    required this.technologiesUsed,
    required this.technologiesUsedInfo,
    required this.cookiePolicyInfo,
    required this.optOut,
    required this.policyOf,
    required this.imprintLinkText,
    required this.privacyPolicyLinkText,
    required this.categories,
    required this.anyDomain,
    required this.day,
    required this.days,
    required this.domain,
    required this.duration,
    required this.informationLoadingNotPossible,
    required this.hour,
    required this.hours,
    required this.identifier,
    required this.maximumAgeCookieStorage,
    required this.minute,
    required this.minutes,
    required this.month,
    required this.months,
    required this.multipleDomains,
    required this.no,
    required this.nonCookieStorage,
    required this.seconds,
    required this.session,
    required this.loadingStorageInformation,
    required this.storageInformation,
    required this.detailedStorageInformation,
    required this.tryAgain,
    required this.type,
    required this.year,
    required this.years,
    required this.yes,
    required this.storageInformationDescription,
    required this.btnBannerReadMore,
    required this.linkToDpaInfo,
    required this.second,
    required this.consent,
    required this.secondLayerDescriptionHtml,
    required this.secondLayerTitle,
  });

  final String btnAcceptAll;
  final String btnDeny;
  final String btnSave;
  final String firstLayerTitle;
  final String accepted;
  final String denied;
  final String date;
  final String decision;
  final String dataCollectedList;
  final String dataCollectedInfo;
  final String locationOfProcessing;
  final String transferToThirdCountries;
  final String dataPurposes;
  final String dataPurposesInfo;
  final String dataRecipientsList;
  final String descriptionOfService;
  final String history;
  final String historyDescription;
  final String legalBasisList;
  final String legalBasisInfo;
  final String processingCompanyTitle;
  final String technologiesUsed;
  final String technologiesUsedInfo;
  final String cookiePolicyInfo;
  final String optOut;
  final String policyOf;
  final String imprintLinkText;
  final String privacyPolicyLinkText;
  final String categories;
  final String anyDomain;
  final String day;
  final String days;
  final String domain;
  final String duration;
  final String informationLoadingNotPossible;
  final String hour;
  final String hours;
  final String identifier;
  final String maximumAgeCookieStorage;
  final String minute;
  final String minutes;
  final String month;
  final String months;
  final String multipleDomains;
  final String no;
  final String nonCookieStorage;
  final String seconds;
  final String session;
  final String loadingStorageInformation;
  final String storageInformation;
  final String detailedStorageInformation;
  final String tryAgain;
  final String type;
  final String year;
  final String years;
  final String yes;
  final String storageInformationDescription;
  final String btnBannerReadMore;
  final String linkToDpaInfo;
  final String second;
  final String consent;
  final String secondLayerDescriptionHtml;
  final String secondLayerTitle;

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is UsercentricsLabels &&
          runtimeType == other.runtimeType &&
          btnAcceptAll == other.btnAcceptAll &&
          btnDeny == other.btnDeny &&
          btnSave == other.btnSave &&
          firstLayerTitle == other.firstLayerTitle &&
          accepted == other.accepted &&
          denied == other.denied &&
          date == other.date &&
          decision == other.decision &&
          dataCollectedList == other.dataCollectedList &&
          dataCollectedInfo == other.dataCollectedInfo &&
          locationOfProcessing == other.locationOfProcessing &&
          transferToThirdCountries == other.transferToThirdCountries &&
          dataPurposes == other.dataPurposes &&
          dataPurposesInfo == other.dataPurposesInfo &&
          dataRecipientsList == other.dataRecipientsList &&
          descriptionOfService == other.descriptionOfService &&
          history == other.history &&
          historyDescription == other.historyDescription &&
          legalBasisList == other.legalBasisList &&
          legalBasisInfo == other.legalBasisInfo &&
          processingCompanyTitle == other.processingCompanyTitle &&
          technologiesUsed == other.technologiesUsed &&
          technologiesUsedInfo == other.technologiesUsedInfo &&
          cookiePolicyInfo == other.cookiePolicyInfo &&
          optOut == other.optOut &&
          policyOf == other.policyOf &&
          imprintLinkText == other.imprintLinkText &&
          privacyPolicyLinkText == other.privacyPolicyLinkText &&
          categories == other.categories &&
          anyDomain == other.anyDomain &&
          day == other.day &&
          days == other.days &&
          domain == other.domain &&
          duration == other.duration &&
          informationLoadingNotPossible ==
              other.informationLoadingNotPossible &&
          hour == other.hour &&
          hours == other.hours &&
          identifier == other.identifier &&
          maximumAgeCookieStorage == other.maximumAgeCookieStorage &&
          minute == other.minute &&
          minutes == other.minutes &&
          month == other.month &&
          months == other.months &&
          multipleDomains == other.multipleDomains &&
          no == other.no &&
          nonCookieStorage == other.nonCookieStorage &&
          seconds == other.seconds &&
          session == other.session &&
          loadingStorageInformation == other.loadingStorageInformation &&
          storageInformation == other.storageInformation &&
          detailedStorageInformation == other.detailedStorageInformation &&
          tryAgain == other.tryAgain &&
          type == other.type &&
          year == other.year &&
          years == other.years &&
          yes == other.yes &&
          storageInformationDescription ==
              other.storageInformationDescription &&
          btnBannerReadMore == other.btnBannerReadMore &&
          linkToDpaInfo == other.linkToDpaInfo &&
          second == other.second &&
          consent == other.consent &&
          secondLayerDescriptionHtml == other.secondLayerDescriptionHtml &&
          secondLayerTitle == other.secondLayerTitle;

  @override
  int get hashCode =>
      btnAcceptAll.hashCode +
      btnDeny.hashCode +
      btnSave.hashCode +
      firstLayerTitle.hashCode +
      accepted.hashCode +
      denied.hashCode +
      date.hashCode +
      decision.hashCode +
      dataCollectedList.hashCode +
      dataCollectedInfo.hashCode +
      locationOfProcessing.hashCode +
      transferToThirdCountries.hashCode +
      dataPurposes.hashCode +
      dataPurposesInfo.hashCode +
      dataRecipientsList.hashCode +
      descriptionOfService.hashCode +
      history.hashCode +
      historyDescription.hashCode +
      legalBasisList.hashCode +
      legalBasisInfo.hashCode +
      processingCompanyTitle.hashCode +
      technologiesUsed.hashCode +
      technologiesUsedInfo.hashCode +
      cookiePolicyInfo.hashCode +
      optOut.hashCode +
      policyOf.hashCode +
      imprintLinkText.hashCode +
      privacyPolicyLinkText.hashCode +
      categories.hashCode +
      anyDomain.hashCode +
      day.hashCode +
      days.hashCode +
      domain.hashCode +
      duration.hashCode +
      informationLoadingNotPossible.hashCode +
      hour.hashCode +
      hours.hashCode +
      identifier.hashCode +
      maximumAgeCookieStorage.hashCode +
      minute.hashCode +
      minutes.hashCode +
      month.hashCode +
      months.hashCode +
      multipleDomains.hashCode +
      no.hashCode +
      nonCookieStorage.hashCode +
      seconds.hashCode +
      session.hashCode +
      loadingStorageInformation.hashCode +
      storageInformation.hashCode +
      detailedStorageInformation.hashCode +
      tryAgain.hashCode +
      type.hashCode +
      year.hashCode +
      years.hashCode +
      yes.hashCode +
      storageInformationDescription.hashCode +
      btnBannerReadMore.hashCode +
      linkToDpaInfo.hashCode +
      second.hashCode +
      consent.hashCode +
      secondLayerDescriptionHtml.hashCode +
      secondLayerTitle.hashCode;

  @override
  String toString() => "$UsercentricsLabels($hashCode)";
}

==> 2.8.0.tar.gz: lib/src/model/labels.dart <==
class UsercentricsLabels {
  const UsercentricsLabels({
    required this.btnAcceptAll,
    required this.btnDeny,
    required this.btnSave,
    required this.firstLayerTitle,
    required this.accepted,
    required this.denied,
    required this.date,
    required this.decision,
    required this.dataCollectedList,
    required this.dataCollectedInfo,
    required this.locationOfProcessing,
    required this.transferToThirdCountries,
    required this.dataPurposes,
    required this.dataPurposesInfo,
    required this.dataRecipientsList,
    required this.descriptionOfService,
    required this.history,
    required this.historyDescription,
    required this.legalBasisList,
    required this.legalBasisInfo,
    required this.processingCompanyTitle,
    required this.technologiesUsed,
    required this.technologiesUsedInfo,
    required this.cookiePolicyInfo,
    required this.optOut,
    required this.policyOf,
    required this.imprintLinkText,
    required this.privacyPolicyLinkText,
    required this.categories,
    required this.anyDomain,
    required this.day,
    required this.days,
    required this.domain,
    required this.duration,
    required this.informationLoadingNotPossible,
    required this.hour,
    required this.hours,
    required this.identifier,
    required this.maximumAgeCookieStorage,
    required this.minute,
    required this.minutes,
    required this.month,
    required this.months,
    required this.multipleDomains,
    required this.no,
    required this.nonCookieStorage,
    required this.seconds,
    required this.session,
    required this.loadingStorageInformation,
    required this.storageInformation,
    required this.detailedStorageInformation,
    required this.tryAgain,
    required this.type,
    required this.year,
    required this.years,
    required this.yes,
    required this.storageInformationDescription,
    required this.btnBannerReadMore,
    required this.btnMore,
    required this.linkToDpaInfo,
    required this.second,
    required this.consent,
    required this.secondLayerDescriptionHtml,
    required this.secondLayerTitle,
    required this.retentionPeriod,
    required this.explicit,
  });

  final String btnAcceptAll;
  final String btnDeny;
  final String btnSave;
  final String firstLayerTitle;
  final String accepted;
  final String denied;
  final String date;
  final String decision;
  final String dataCollectedList;
  final String dataCollectedInfo;
  final String locationOfProcessing;
  final String transferToThirdCountries;
  final String dataPurposes;
  final String dataPurposesInfo;
  final String dataRecipientsList;
  final String descriptionOfService;
  final String history;
  final String historyDescription;
  final String legalBasisList;
  final String legalBasisInfo;
  final String processingCompanyTitle;
  final String technologiesUsed;
  final String technologiesUsedInfo;
  final String cookiePolicyInfo;
  final String optOut;
  final String policyOf;
  final String imprintLinkText;
  final String privacyPolicyLinkText;
  final String categories;
  final String anyDomain;
  final String day;
  final String days;
  final String domain;
  final String duration;
  final String informationLoadingNotPossible;
  final String hour;
  final String hours;
  final String identifier;
  final String maximumAgeCookieStorage;
  final String minute;
  final String minutes;
  final String month;
  final String months;
  final String multipleDomains;
  final String no;
  final String nonCookieStorage;
  final String seconds;
  final String session;
  final String loadingStorageInformation;
  final String storageInformation;
  final String detailedStorageInformation;
  final String tryAgain;
  final String type;
  final String year;
  final String years;
  final String yes;
  final String storageInformationDescription;
  final String btnBannerReadMore;
  final String btnMore;
  final String linkToDpaInfo;
  final String second;
  final String consent;
  final String secondLayerDescriptionHtml;
  final String secondLayerTitle;
  final String retentionPeriod;
  final String explicit;

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is UsercentricsLabels &&
          runtimeType == other.runtimeType &&
          btnAcceptAll == other.btnAcceptAll &&
          btnDeny == other.btnDeny &&
          btnSave == other.btnSave &&
          firstLayerTitle == other.firstLayerTitle &&
          accepted == other.accepted &&
          denied == other.denied &&
          date == other.date &&
          decision == other.decision &&
          dataCollectedList == other.dataCollectedList &&
          dataCollectedInfo == other.dataCollectedInfo &&
          locationOfProcessing == other.locationOfProcessing &&
          transferToThirdCountries == other.transferToThirdCountries &&
          dataPurposes == other.dataPurposes &&
          dataPurposesInfo == other.dataPurposesInfo &&
          dataRecipientsList == other.dataRecipientsList &&
          descriptionOfService == other.descriptionOfService &&
          history == other.history &&
          historyDescription == other.historyDescription &&
          legalBasisList == other.legalBasisList &&
          legalBasisInfo == other.legalBasisInfo &&
          processingCompanyTitle == other.processingCompanyTitle &&
          technologiesUsed == other.technologiesUsed &&
          technologiesUsedInfo == other.technologiesUsedInfo &&
          cookiePolicyInfo == other.cookiePolicyInfo &&
          optOut == other.optOut &&
          policyOf == other.policyOf &&
          imprintLinkText == other.imprintLinkText &&
          privacyPolicyLinkText == other.privacyPolicyLinkText &&
          categories == other.categories &&
          anyDomain == other.anyDomain &&
          day == other.day &&
          days == other.days &&
          domain == other.domain &&
          duration == other.duration &&
          informationLoadingNotPossible ==
              other.informationLoadingNotPossible &&
          hour == other.hour &&
          hours == other.hours &&
          identifier == other.identifier &&
          maximumAgeCookieStorage == other.maximumAgeCookieStorage &&
          minute == other.minute &&
          minutes == other.minutes &&
          month == other.month &&
          months == other.months &&
          multipleDomains == other.multipleDomains &&
          no == other.no &&
          nonCookieStorage == other.nonCookieStorage &&
          seconds == other.seconds &&
          session == other.session &&
          loadingStorageInformation == other.loadingStorageInformation &&
          storageInformation == other.storageInformation &&
          detailedStorageInformation == other.detailedStorageInformation &&
          tryAgain == other.tryAgain &&
          type == other.type &&
          year == other.year &&
          years == other.years &&
          yes == other.yes &&
          storageInformationDescription ==
              other.storageInformationDescription &&
          btnBannerReadMore == other.btnBannerReadMore &&
          btnMore == other.btnMore &&
          linkToDpaInfo == other.linkToDpaInfo &&
          second == other.second &&
          consent == other.consent &&
          secondLayerDescriptionHtml == other.secondLayerDescriptionHtml &&
          secondLayerTitle == other.secondLayerTitle &&
          explicit == other.explicit &&
          retentionPeriod == other.retentionPeriod;

  @override
  int get hashCode =>
      btnAcceptAll.hashCode ^
      btnDeny.hashCode ^
      btnSave.hashCode ^
      firstLayerTitle.hashCode ^
      accepted.hashCode ^
      denied.hashCode ^
      date.hashCode ^
      decision.hashCode ^
      dataCollectedList.hashCode ^
      dataCollectedInfo.hashCode ^
      locationOfProcessing.hashCode ^
      transferToThirdCountries.hashCode ^
      dataPurposes.hashCode ^
      dataPurposesInfo.hashCode ^
      dataRecipientsList.hashCode ^
      descriptionOfService.hashCode ^
      history.hashCode ^
      historyDescription.hashCode ^
      legalBasisList.hashCode ^
      legalBasisInfo.hashCode ^
      processingCompanyTitle.hashCode ^
      technologiesUsed.hashCode ^
      technologiesUsedInfo.hashCode ^
      cookiePolicyInfo.hashCode ^
      optOut.hashCode ^
      policyOf.hashCode ^
      imprintLinkText.hashCode ^
      privacyPolicyLinkText.hashCode ^
      categories.hashCode ^
      anyDomain.hashCode ^
      day.hashCode ^
      days.hashCode ^
      domain.hashCode ^
      duration.hashCode ^
      informationLoadingNotPossible.hashCode ^
      hour.hashCode ^
      hours.hashCode ^
      identifier.hashCode ^
      maximumAgeCookieStorage.hashCode ^
      minute.hashCode ^
      minutes.hashCode ^
      month.hashCode ^
      months.hashCode ^
      multipleDomains.hashCode ^
      no.hashCode ^
      nonCookieStorage.hashCode ^
      seconds.hashCode ^
      session.hashCode ^
      loadingStorageInformation.hashCode ^
      storageInformation.hashCode ^
      detailedStorageInformation.hashCode ^
      tryAgain.hashCode ^
      type.hashCode ^
      year.hashCode ^
      years.hashCode ^
      yes.hashCode ^
      storageInformationDescription.hashCode ^
      btnBannerReadMore.hashCode ^
      btnMore.hashCode ^
      linkToDpaInfo.hashCode ^
      second.hashCode ^
      consent.hashCode ^
      secondLayerDescriptionHtml.hashCode ^
      secondLayerTitle.hashCode ^
      explicit.hashCode ^
      retentionPeriod.hashCode;

  @override
  String toString() => "$UsercentricsLabels($hashCode)";
}
